import React, { useState, useRef, useEffect } from 'react';
import { Popover } from 'antd';
import classNames from 'classnames';
import s from './index.less';

export const Tags = (props: any) => {
    const { value, origin, componentAttr } = props;
    if (!Array.isArray(value) || value.length === 0) return null;
    const { options, mode } = componentAttr || {};
    const outStyle: any = {};
    const innerStyle: any = {};
    const itemStyle: any = {};
    if (origin === 'detailForm') {
        outStyle.width = 'auto';
        innerStyle.flexWrap = 'wrap';
        itemStyle.marginBottom = '5px';
    }
    const getColor = (item: any) => {
        let color = '';
        if (options && Array.isArray(options) && options.length > 0) {
            const obj = options.find((ls) => {
                return String(ls.id) === String(item.value);
            }) || {};
            color = obj.color || 'e9eef9';
        }
        return color;
    };

    if (mode !== 'multiple') {
        // 单选
        return (
            <div className={s.container}>
                <span className={s.item} style={{ ...itemStyle, background: `#${getColor(value[0])}` }}>
                    <div className={s.itemBgTxt}>{value[0].text}</div>
                </span>
            </div>
        );
    }

    const [dotVisible, setDotVisible] = useState(false);
    const outer = useRef(null);
    const inner = useRef(null);
    useEffect(() => {
        const outerTarget: any = outer.current;
        const innerTarget: any = inner.current;
        let visible = false;
        if (outerTarget && innerTarget && origin !== 'detailForm') {
            if (innerTarget.clientWidth > outerTarget.clientWidth) {
                visible = true;
            } else {
                visible = false;
            }
        }
        setDotVisible(visible);
    }, [value]);

    return (
        <div className={s.container}>
            <div className={s.outContainer} ref={outer} style={outStyle}>
                <div className={s.innerContainer} ref={inner} style={innerStyle}>
                    {dotVisible ? (
                        <Popover
                            placement="left"
                            overlayClassName={s.popContainer}
                            content={
                                <div className={s.popContent}>
                                    {value.map((item, index) => {
                                        return (
                                            <span
                                                className={s.popItem}
                                                key={index}
                                                style={{ background: `#${getColor(item)}` }}
                                            >
                                                <div className={s.popItemBgTxt}>{item.text}</div>
                                            </span>
                                        );
                                    })}
                                </div>
                            }
                        >
                            <div className={s.content} style={innerStyle}>
                                {value.map((item, index) => {
                                    return (
                                        <span
                                            key={index}
                                            className={classNames(s.item, s.multi)}
                                            style={{ ...itemStyle, background: `#${getColor(item)}` }}
                                        >
                                            <div className={s.itemBgTxt}>{item.text}</div>
                                        </span>
                                    );
                                })}
                            </div>
                        </Popover>
                    ) : (
                        <div className={s.content} style={innerStyle}>
                            {value.map((item, index) => {
                                return (
                                    <span
                                        key={index}
                                        className={classNames(s.item, s.multi)}
                                        style={{ ...itemStyle, background: `#${getColor(item)}` }}
                                    >
                                        <div className={s.itemBgTxt}>{item.text}</div>
                                    </span>
                                );
                            })}
                        </div>
                    )}
                </div>
            </div>
        </div>
    );
};
export default Tags;
